==> zio-aws-apigatewayv2_2.12-5.17.104.13-sources.jar: zio/aws/apigatewayv2/model/JWTConfiguration.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  UriWithLengthBetween1And2048,
  __string
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class JWTConfiguration(
    audience: Option[Iterable[__string]] = None,
    issuer: Option[UriWithLengthBetween1And2048] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration = {
    import JWTConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
      .builder()
      .optionallyWith(
        audience.map(value =>
          value.map { item =>
            __string.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.audience)
      .optionallyWith(
        issuer.map(value =>
          UriWithLengthBetween1And2048.unwrap(value): java.lang.String
        )
      )(_.issuer)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.JWTConfiguration.ReadOnly =
    zio.aws.apigatewayv2.model.JWTConfiguration.wrap(buildAwsValue())
}
object JWTConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.JWTConfiguration =
      zio.aws.apigatewayv2.model.JWTConfiguration(
        audience.map(value => value),
        issuer.map(value => value)
      )
    def audience: Option[List[__string]]
    def issuer: Option[UriWithLengthBetween1And2048]
    def getAudience: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("audience", audience)
    def getIssuer: ZIO[Any, AwsError, UriWithLengthBetween1And2048] =
      AwsError.unwrapOptionField("issuer", issuer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
  ) extends zio.aws.apigatewayv2.model.JWTConfiguration.ReadOnly {
    override val audience: Option[List[__string]] = scala
      .Option(impl.audience())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.primitives.__string(item)
        }.toList
      )
    override val issuer: Option[UriWithLengthBetween1And2048] = scala
      .Option(impl.issuer())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .UriWithLengthBetween1And2048(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
  ): zio.aws.apigatewayv2.model.JWTConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.13-5.17.158.3-sources.jar: zio/aws/apigatewayv2/model/JWTConfiguration.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  UriWithLengthBetween1And2048,
  __string
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class JWTConfiguration(
    audience: Option[Iterable[__string]] = None,
    issuer: Option[UriWithLengthBetween1And2048] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration = {
    import JWTConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
      .builder()
      .optionallyWith(
        audience.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.audience)
      .optionallyWith(
        issuer.map(value =>
          UriWithLengthBetween1And2048.unwrap(value): java.lang.String
        )
      )(_.issuer)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.JWTConfiguration.ReadOnly =
    zio.aws.apigatewayv2.model.JWTConfiguration.wrap(buildAwsValue())
}
object JWTConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.JWTConfiguration =
      zio.aws.apigatewayv2.model.JWTConfiguration(
        audience.map(value => value),
        issuer.map(value => value)
      )
    def audience: Option[List[__string]]
    def issuer: Option[UriWithLengthBetween1And2048]
    def getAudience: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("audience", audience)
    def getIssuer: ZIO[Any, AwsError, UriWithLengthBetween1And2048] =
      AwsError.unwrapOptionField("issuer", issuer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
  ) extends zio.aws.apigatewayv2.model.JWTConfiguration.ReadOnly {
    override val audience: Option[List[__string]] = scala
      .Option(impl.audience())
      .map(value =>
        value.asScala.map { item =>
          item: __string
        }.toList
      )
    override val issuer: Option[UriWithLengthBetween1And2048] = scala
      .Option(impl.issuer())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .UriWithLengthBetween1And2048(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.JWTConfiguration
  ): zio.aws.apigatewayv2.model.JWTConfiguration.ReadOnly = new Wrapper(impl)
}
